==> boschrpamagicbox-0.2.62.tar.gz: boschrpamagicbox-0.2.62/src/BoschRpaMagicBox/common_config.py <==
USERNAME_CSS_SELECTOR = '#sap-user'
PASSWORD_CSS_SELECTOR = '#sap-password'
LOGIN_BUTTON_CSS_SELECTOR = "#LOGON_BUTTON"
LOADING_WINDOW_ID_NAME = "ur-loading-itm2"
MAIN_PAGE_HEADER_CSS_SELECTOR = "#cuaheader-title"
IFRAME_CSS_SELECTOR = "iframe#ITSFRAME1"
CENTER_BOX_ID = "CenterBox"
INFO_BOX_ID = "Infobox"
T_CODE_CSS_SELECTOR = "#ToolbarOkCode"
OPEN_AT_KEY_DATE_CSS_SELECTOR = "div.lsRasterLayout div.lsRLItemCnt:nth-child(3) input[title='Open Items at Key Date']"
EXECUTION_BUTTON_CSS_SELECTOR = "div[title='Execute (F8)']"
COPY_BUTTON_CSS_SELECTOR = "div[title='Copy (F8)']"
IMPORT_FILE_CSS_SELECTOR = "div[title='Import from Text File (Shift+F11)']"
IMPORT_FILE_OK_CSS_SELECTOR = "#UpDownDialogChoose"
DELETE_ENTIRE_SELECTION_BUTTON_CSS_SELECTOR = "div[title='Delete Entire Selection (Shift+F4)']"
LAYOUT_CSS_SELECTOR = "input[title='Layout']"
DATA_PAGE_WAIT_CSS_SELECTOR = "div#userpanel"
EXCEL_FILE_NAME_INPUT_CSS_SELECTOR = "table#popupDialogML input#popupDialogInputField"
SECTION_NAME = "G/L account selection"
MULTIPLE_SECTION_BUTTON_INDEX = 5
MULTIPLE_WINDOW_FIRST_INPUT_CSS_SELECTOR = "tr[vpm='mrss-cont'] td.urST5OuterOffBrd:first-child div[vpm='mrss-cont'] table.urST5OuterOffBrd tbody tr:first-child td input.lsField__input"
SELECT_RANGES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(2) div:first-child"
EXCLUDE_SINGLE_VALUES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(3) div:first-child"
EXCLUDE_RANGES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(4) div:first-child"
FILE_UPLOAD_INPUT_CSS_SELECTOR = "input[title='File Name']"
FILE_UPLOAD_CONTINUE_CSS_SELECTOR = "div#webguiPopups div:nth-child(2) div[title='Continue (Enter)']"
UPLOAD_ATTACHMENT_BUTTON_CSS_SELECTOR = "div[title^='Services']"
CREATE_CSS_SELECTOR = "tr[aria-label='Create...']"
UPLOAD_ATTACHMENT_CHOICES_CSS_SELECTOR = "div#menu_1_1_bp div.lsMnuCnt table.lsMnuTable tr"
UPLOAD_ATTACHMENT_TEXT_CSS_SELECTOR = "td.urMnuTxt span"
UPLOAD_ATTACHMENT_DOCUMENT_TYPES_OVERVIEW_CSS_SELECTOR = "tr[vpm='mrss-cont']"
# UPLOAD_ATTACHMENT_DOCUMENT_TYPES_CHOICES_CSS_SELECTOR = "tr[vpm='mrss-cont'] td:first-child div[vpm='mrss-cont'] div.urBorderBox:first-child table:first-child tbody:nth-child(2) tr[id^='tree'] table[ct='MG'] span.lsTextView--root"
UPLOAD_ATTACHMENT_DOCUMENT_TYPES_CHOICES_CSS_SELECTOR = "tr[vpm='mrss-cont'] td:first-child div[vpm='mrss-cont'] td[id^='tree'] span[role='presentation'] span[id^='tree']"
UPLOAD_CONFIRM_BUTTON_CSS_SELECTOR = "div#UpDownDialogChoose"
UPLOAD_ATTACHMENT_COMPLETE_CSS_SELECTOR = "div[title='Continue (Enter)']"
TARGET_DOCUMENT_DICT = {'JPG': ['FI DesktopLink Attachment JPG'],
                        'PDF': ['FI DesktopLink Attachment PDF'],
                        'MSG': ['FI DesktopLink Attachment eMail', 'FI DesktopLink Attachment MSG']}
ERROR_ICON_CSS_SELECTOR = "span.lsMessageBar__image--Error"
DROP_DOWN_ICON_CSS_SELECTOR = "td.lsField__helpcontainer span.lsField__help"
BANK_STATEMENT_LIST_CSS_SELECTOR = "div.lsListbox__values"
BANK_STATEMENT_FILE_INPUT_CSS_SELECTOR = "input[title='Statement file']"
BANK_STATEMENT_FILE_SPAN_CSS_SELECTOR = "span[title='Statement file']"
BACK_CSS_SELECTOR = "div[title='Back (F3)']"
LOG_OFF_CSS_SELECTOR = "div[title='Log Off (Shift+F3)']"
ALWAYS_EXCEL_CSS_SELECTOR = "span[aria-label='Always Use Selected Format']"
# FIREFOX_BINARY_DEFAULT_LOCATION = r'C:\Program Files\Mozilla Firefox\firefox.exe'
EXCEL_CONTINUE_CSS_SELECTOR = "div[title='Continue (Enter)']"
LOGIN_CONTINUE_BUTTON_CSS_SELECTOR = "span[id$='CONTINUE_BUTTON-caption']"
Y01F_FILE_NAME_INPUT_CSS_SELECTOR = "input[title='File for Report Writer output']"
Y01F_DOWNLOAD_CONTINUE_BUTTON_CSS_SELECTOR = "div[lsdata*=\"'Continue'\"]"
CANCEL_BY_USER_CSS_SELECTOR = ".lsMessageBar__text "
SE16_LAYOUT_TH_CSS_SELECTOR = ".urPWContentTableCellWorkaround div.lsContainer--verticalsizing-fill table[id$='-mrss-hdr-none-content'] th:first-child"
SE16_LAYOUT_SPAN_CSS_SELECTOR = ".urPWContentTableCellWorkaround table[id$='-mrss-cont-none-content'] tbody tr td:first-child span span"

==> boschrpamagicbox-0.2.72.tar.gz: boschrpamagicbox-0.2.72/src/BoschRpaMagicBox/common_config.py <==
USERNAME_CSS_SELECTOR = '#sap-user'
PASSWORD_CSS_SELECTOR = '#sap-password'
LOGIN_BUTTON_CSS_SELECTOR = "#LOGON_BUTTON"
LOADING_WINDOW_ID_NAME = "ur-loading-itm2"
MAIN_PAGE_HEADER_CSS_SELECTOR = "#cuaheader-title"
IFRAME_CSS_SELECTOR = "iframe#ITSFRAME1"
CENTER_BOX_ID = "CenterBox"
INFO_BOX_ID = "Infobox"
T_CODE_CSS_SELECTOR = "#ToolbarOkCode"
OPEN_AT_KEY_DATE_CSS_SELECTOR = "div.lsRasterLayout div.lsRLItemCnt:nth-child(3) input[title='Open Items at Key Date']"
EXECUTION_BUTTON_CSS_SELECTOR = "div[title='Execute (F8)']"
COPY_BUTTON_CSS_SELECTOR = "div[title='Copy (F8)']"
IMPORT_FILE_CSS_SELECTOR = "div[title='Import from Text File (Shift+F11)']"
IMPORT_FILE_OK_CSS_SELECTOR = "#UpDownDialogChoose"
DELETE_ENTIRE_SELECTION_BUTTON_CSS_SELECTOR = "div[title='Delete Entire Selection (Shift+F4)']"
LAYOUT_CSS_SELECTOR = "input[title='Layout']"
DATA_PAGE_WAIT_CSS_SELECTOR = "div#userpanel"
EXCEL_FILE_NAME_INPUT_CSS_SELECTOR = "table#popupDialogML input#popupDialogInputField"
SECTION_NAME = "G/L account selection"
MULTIPLE_SECTION_BUTTON_INDEX = 5
MULTIPLE_WINDOW_FIRST_INPUT_CSS_SELECTOR = "tr[vpm='mrss-cont'] td.urST5OuterOffBrd:first-child div[vpm='mrss-cont'] table.urST5OuterOffBrd tbody tr:first-child td input.lsField__input"
SELECT_RANGES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(2) div:first-child"
SELECT_RANGES_QUERY_CSS_SELECTOR = "td.urPWContentTableCellWorkaround td.lsTbsPanelCnt td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(2) div:first-child"
EXCLUDE_SINGLE_VALUES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(3) div:first-child"
EXCLUDE_RANGES_CSS_SELECTOR = "td.lsTbsPanel2 div:first-child div.lsTbsItem--scrollable:nth-child(4) div:first-child"
FILE_UPLOAD_INPUT_CSS_SELECTOR = "input[title='File Name']"
FILE_UPLOAD_CONTINUE_CSS_SELECTOR = "div#webguiPopups div:nth-child(2) div[title='Continue (Enter)']"
UPLOAD_ATTACHMENT_BUTTON_CSS_SELECTOR = "div[title^='Services']"
CREATE_CSS_SELECTOR = "tr[aria-label='Create...']"
UPLOAD_ATTACHMENT_CHOICES_CSS_SELECTOR = "div#menu_1_1_bp div.lsMnuCnt table.lsMnuTable tr"
UPLOAD_ATTACHMENT_TEXT_CSS_SELECTOR = "td.urMnuTxt span"
UPLOAD_ATTACHMENT_DOCUMENT_TYPES_OVERVIEW_CSS_SELECTOR = "tr[vpm='mrss-cont']"
# UPLOAD_ATTACHMENT_DOCUMENT_TYPES_CHOICES_CSS_SELECTOR = "tr[vpm='mrss-cont'] td:first-child div[vpm='mrss-cont'] div.urBorderBox:first-child table:first-child tbody:nth-child(2) tr[id^='tree'] table[ct='MG'] span.lsTextView--root"
UPLOAD_ATTACHMENT_DOCUMENT_TYPES_CHOICES_CSS_SELECTOR = "tr[vpm='mrss-cont'] td:first-child div[vpm='mrss-cont'] td[id^='tree'] span[role='presentation'] span[id^='tree']"
UPLOAD_CONFIRM_BUTTON_CSS_SELECTOR = "div#UpDownDialogChoose"
UPLOAD_ATTACHMENT_COMPLETE_CSS_SELECTOR = "div[title='Continue (Enter)']"
TARGET_DOCUMENT_DICT = {'JPG': ['FI DesktopLink Attachment JPG'],
                        'PDF': ['FI DesktopLink Attachment PDF'],
                        'MSG': ['FI DesktopLink Attachment eMail', 'FI DesktopLink Attachment MSG']}
ERROR_ICON_CSS_SELECTOR = "span.lsMessageBar__image--Error"
DROP_DOWN_ICON_CSS_SELECTOR = "td.lsField__helpcontainer span.lsField__help"
BANK_STATEMENT_LIST_CSS_SELECTOR = "div.lsListbox__values"
BANK_STATEMENT_FILE_INPUT_CSS_SELECTOR = "input[title='Statement file']"
BANK_STATEMENT_FILE_SPAN_CSS_SELECTOR = "span[title='Statement file']"
BACK_CSS_SELECTOR = "div[title='Back (F3)']"
LOG_OFF_CSS_SELECTOR = "div[title='Log Off (Shift+F3)']"
ALWAYS_EXCEL_CSS_SELECTOR = "span[aria-label='Always Use Selected Format']"
# FIREFOX_BINARY_DEFAULT_LOCATION = r'C:\Program Files\Mozilla Firefox\firefox.exe'
EXCEL_CONTINUE_CSS_SELECTOR = "div[title='Continue (Enter)']"
LOGIN_CONTINUE_BUTTON_CSS_SELECTOR = "span[id$='CONTINUE_BUTTON-caption']"
Y01F_FILE_NAME_INPUT_CSS_SELECTOR = "input[title='File for Report Writer output']"
Y01F_DOWNLOAD_CONTINUE_BUTTON_CSS_SELECTOR = "div[lsdata*=\"'Continue'\"]"
CANCEL_BY_USER_CSS_SELECTOR = ".lsMessageBar__text "
SE16_LAYOUT_TH_CSS_SELECTOR = ".urPWContentTableCellWorkaround div.lsContainer--verticalsizing-fill table[id$='-mrss-hdr-none-content'] th:first-child"
SE16_LAYOUT_SPAN_CSS_SELECTOR = ".urPWContentTableCellWorkaround table[id$='-mrss-cont-none-content'] tbody tr td:first-child span span"
